# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mlp_api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import vo_pb2 as vo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mlp_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\rmlp_api.proto\x1a\x08vo.proto\"I\n\x14\x43reateProjectRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x04meta\x18\x02 \x01(\x0b\x32\x15.ProjectMetadataDelta\"!\n\x11GetProjectRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"J\n\x13ProjectInfoResponse\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"V\n\x10\x43reateJobRequest\x12\x13\n\x0bproject_uid\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1f\n\x04meta\x18\x03 \x01(\x0b\x32\x11.JobMetadataDelta\"2\n\rGetJobRequest\x12\x13\n\x0bproject_uid\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\"q\n\x0fJobInfoResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\x0c\x12\x14\n\x0cproject_name\x18\x03 \x01(\t\x12\x13\n\x0bproject_uid\x18\x04 \x01(\x0c\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"g\n\x12StartJobRunRequest\x12\x13\n\x0bproject_uid\x18\x01 \x01(\x0c\x12\x0f\n\x07job_uid\x18\x02 \x01(\x0c\x12\r\n\x05title\x18\x03 \x01(\t\x12\x1c\n\x06inputs\x18\x04 \x03(\x0b\x32\x0c.JobRunInput\"P\n\x12JobRunInfoResponse\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x13\n\x0bproject_uid\x18\x02 \x01(\x0c\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"C\n\x10LogJobRunRequest\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0f\n\x07\x64\x65tails\x18\x02 \x01(\t\x12\x11\n\tlog_title\x18\x03 \x01(\t\"B\n\x11\x46\x61ilJobRunRequest\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x03 \x01(\t\"$\n\x15\x43ompleteJobRunRequest\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\"Y\n\x10\x41\x64\x64SystemRequest\x12\x13\n\x0bproject_uid\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\"\n\x04meta\x18\x03 \x01(\x0b\x32\x14.SystemMetadataDelta\"5\n\x10GetSystemRequest\x12\x13\n\x0bproject_uid\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\"t\n\x12SystemInfoResponse\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x13\n\x0bproject_uid\x18\x02 \x01(\x0c\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0cproject_name\x18\x04 \x01(\t\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"\x88\x01\n\x17\x41\x64\x64SystemVersionRequest\x12\x12\n\nsystem_uid\x18\x01 \x01(\x0c\x12\r\n\x05title\x18\x02 \x01(\t\x12#\n\x06inputs\x18\x03 \x03(\x0b\x32\x13.SystemVersionInput\x12%\n\x07outputs\x18\x04 \x03(\x0b\x32\x14.SystemVersionOutput\"A\n\x18\x41\x64\x64SystemVersionResponse\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"6\n\x11GetDatasetRequest\x12\x13\n\x0bproject_uid\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\"^\n\x14\x43reateDatasetRequest\x12\x13\n\x0bproject_uid\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\x12#\n\x04meta\x18\x03 \x01(\x0b\x32\x15.DatasetMetadataDelta\"\xe4\x01\n\x13\x44\x61tasetInfoResponse\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x13\n\x0bproject_uid\x18\x02 \x01(\x0c\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0cproject_name\x18\x04 \x01(\t\x12\x18\n\x10update_timestamp\x18\t \x01(\x03\x12\x13\n\x0b\x64\x61ta_format\x18\n \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\x12\x13\n\x0blocation_id\x18\x0c \x01(\t\x12\x14\n\x0clocation_uri\x18\r \x01(\t\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"H\n\x1cGetLastDatasetVersionRequest\x12\x13\n\x0bproject_uid\x18\x01 \x01(\x0c\x12\x13\n\x0b\x64\x61taset_uid\x18\x02 \x01(\x0c\"S\n\x16\x44\x61tasetVersionResponse\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12\x12\n\nno_version\x18\x02 \x01(\x08\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"\xa7\x01\n\x10\x44\x61tasetChangeSet\x12\x13\n\x0b\x64\x61taset_uid\x18\x01 \x01(\x0c\x12\x1a\n\x12parent_version_uid\x18\x02 \x01(\x0c\x12\x1b\n\x05items\x18\x03 \x03(\x0b\x32\x0c.DatasetItem\x12\x13\n\x0b\x63lean_slate\x18\x04 \x01(\x08\x12\x0e\n\x06remove\x18\x05 \x03(\t\x12 \n\x06inputs\x18\x06 \x03(\x0b\x32\x10.DatasetVerInput\"C\n\rDatasetCommit\x12\r\n\x05title\x18\x01 \x01(\t\x12#\n\x08\x64\x61tasets\x18\x02 \x03(\x0b\x32\x11.DatasetChangeSet\"C\n\rCommitRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12#\n\x08\x64\x61tasets\x18\x07 \x03(\x0b\x32\x11.DatasetChangeSet\"D\n\x0e\x43ommitResponse\x12\x18\n\x10\x64\x61taset_versions\x18\x01 \x03(\x0c\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"\r\n\x0bStatRequest\"9\n\x0cStatResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError\"H\n\x14UpdateDatasetRequest\x12\x0b\n\x03uid\x18\x01 \x01(\x0c\x12#\n\x04meta\x18\x02 \x01(\x0b\x32\x15.DatasetMetadataDelta\"\xc6\x01\n\x08\x41piError\x12\x19\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x0b.StatusCode\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0bsubject_uid\x18\x03 \x01(\x0c\x12\x14\n\x0csubject_name\x18\x04 \x01(\t\x12\x12\n\nfield_name\x18\x05 \x01(\t\x12\x0f\n\x07\x64\x65tails\x18\x06 \x03(\t\x12\x14\n\x0cproject_name\x18\x07 \x01(\t\x12\x13\n\x0bproject_uid\x18\x08 \x01(\t\x12\x13\n\x0bmethod_name\x18\t \x01(\t\")\n\rEmptyResponse\x12\x18\n\x05\x65rror\x18\x64 \x01(\x0b\x32\t.ApiError*\xf1\x02\n\nStatusCode\x12\x06\n\x02OK\x10\x00\x12\r\n\tCANCELLED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x13\n\x0fUNAUTHENTICATED\x10\x10\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x12\x0c\n\x08\x42\x41\x44_NAME\x10\x64\x12\x0e\n\nNAME_TAKEN\x10\x65\x12\x14\n\x10VERSION_MISMATCH\x10\x66\x32\xd6\x07\n\x07\x43\x61talog\x12>\n\rCreateProject\x12\x15.CreateProjectRequest\x1a\x14.ProjectInfoResponse\"\x00\x12\x38\n\nGetProject\x12\x12.GetProjectRequest\x1a\x14.ProjectInfoResponse\"\x00\x12\x35\n\tAddSystem\x12\x11.AddSystemRequest\x1a\x13.SystemInfoResponse\"\x00\x12\x35\n\tGetSystem\x12\x11.GetSystemRequest\x1a\x13.SystemInfoResponse\"\x00\x12I\n\x10\x41\x64\x64SystemVersion\x12\x18.AddSystemVersionRequest\x1a\x19.AddSystemVersionResponse\"\x00\x12\x32\n\tCreateJob\x12\x11.CreateJobRequest\x1a\x10.JobInfoResponse\"\x00\x12,\n\x06GetJob\x12\x0e.GetJobRequest\x1a\x10.JobInfoResponse\"\x00\x12\x39\n\x0bStartJobRun\x12\x13.StartJobRunRequest\x1a\x13.JobRunInfoResponse\"\x00\x12\x30\n\tLogJobRun\x12\x11.LogJobRunRequest\x1a\x0e.EmptyResponse\"\x00\x12\x32\n\nFailJobRun\x12\x12.FailJobRunRequest\x1a\x0e.EmptyResponse\"\x00\x12:\n\x0e\x43ompleteJobRun\x12\x16.CompleteJobRunRequest\x1a\x0e.EmptyResponse\"\x00\x12>\n\rCreateDataset\x12\x15.CreateDatasetRequest\x1a\x14.DatasetInfoResponse\"\x00\x12\x38\n\nGetDataset\x12\x12.GetDatasetRequest\x1a\x14.DatasetInfoResponse\"\x00\x12\x38\n\rUpdateDataset\x12\x15.UpdateDatasetRequest\x1a\x0e.EmptyResponse\"\x00\x12Q\n\x15GetLastDatasetVersion\x12\x1d.GetLastDatasetVersionRequest\x1a\x17.DatasetVersionResponse\"\x00\x12+\n\x06\x43ommit\x12\x0e.CommitRequest\x1a\x0f.CommitResponse\"\x00\x12%\n\x04Stat\x12\x0c.StatRequest\x1a\r.StatResponse\"\x00\x62\x06proto3')
  ,
  dependencies=[vo__pb2.DESCRIPTOR,])

_STATUSCODE = _descriptor.EnumDescriptor(
  name='StatusCode',
  full_name='StatusCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ARGUMENT', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEADLINE_EXCEEDED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_EXISTS', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_DENIED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNAUTHENTICATED', index=8, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_EXHAUSTED', index=9, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED_PRECONDITION', index=10, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ABORTED', index=11, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_RANGE', index=12, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIMPLEMENTED', index=13, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL', index=14, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNAVAILABLE', index=15, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATA_LOSS', index=16, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_NAME', index=17, number=100,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_TAKEN', index=18, number=101,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERSION_MISMATCH', index=19, number=102,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2613,
  serialized_end=2982,
)
_sym_db.RegisterEnumDescriptor(_STATUSCODE)

StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
OK = 0
CANCELLED = 1
UNKNOWN = 2
INVALID_ARGUMENT = 3
DEADLINE_EXCEEDED = 4
NOT_FOUND = 5
ALREADY_EXISTS = 6
PERMISSION_DENIED = 7
UNAUTHENTICATED = 16
RESOURCE_EXHAUSTED = 8
FAILED_PRECONDITION = 9
ABORTED = 10
OUT_OF_RANGE = 11
UNIMPLEMENTED = 12
INTERNAL = 13
UNAVAILABLE = 14
DATA_LOSS = 15
BAD_NAME = 100
NAME_TAKEN = 101
VERSION_MISMATCH = 102



_CREATEPROJECTREQUEST = _descriptor.Descriptor(
  name='CreateProjectRequest',
  full_name='CreateProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CreateProjectRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='CreateProjectRequest.meta', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=100,
)


_GETPROJECTREQUEST = _descriptor.Descriptor(
  name='GetProjectRequest',
  full_name='GetProjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='GetProjectRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=135,
)


_PROJECTINFORESPONSE = _descriptor.Descriptor(
  name='ProjectInfoResponse',
  full_name='ProjectInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='ProjectInfoResponse.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='ProjectInfoResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='ProjectInfoResponse.error', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=211,
)


_CREATEJOBREQUEST = _descriptor.Descriptor(
  name='CreateJobRequest',
  full_name='CreateJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='CreateJobRequest.project_uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CreateJobRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='CreateJobRequest.meta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=299,
)


_GETJOBREQUEST = _descriptor.Descriptor(
  name='GetJobRequest',
  full_name='GetJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='GetJobRequest.project_uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='GetJobRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=351,
)


_JOBINFORESPONSE = _descriptor.Descriptor(
  name='JobInfoResponse',
  full_name='JobInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='JobInfoResponse.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='JobInfoResponse.uid', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_name', full_name='JobInfoResponse.project_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='JobInfoResponse.project_uid', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='JobInfoResponse.error', index=4,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=353,
  serialized_end=466,
)


_STARTJOBRUNREQUEST = _descriptor.Descriptor(
  name='StartJobRunRequest',
  full_name='StartJobRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='StartJobRunRequest.project_uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job_uid', full_name='StartJobRunRequest.job_uid', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='StartJobRunRequest.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='StartJobRunRequest.inputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=468,
  serialized_end=571,
)


_JOBRUNINFORESPONSE = _descriptor.Descriptor(
  name='JobRunInfoResponse',
  full_name='JobRunInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='JobRunInfoResponse.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='JobRunInfoResponse.project_uid', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='JobRunInfoResponse.error', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=653,
)


_LOGJOBRUNREQUEST = _descriptor.Descriptor(
  name='LogJobRunRequest',
  full_name='LogJobRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='LogJobRunRequest.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='LogJobRunRequest.details', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='log_title', full_name='LogJobRunRequest.log_title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=722,
)


_FAILJOBRUNREQUEST = _descriptor.Descriptor(
  name='FailJobRunRequest',
  full_name='FailJobRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='FailJobRunRequest.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='FailJobRunRequest.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='FailJobRunRequest.details', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=790,
)


_COMPLETEJOBRUNREQUEST = _descriptor.Descriptor(
  name='CompleteJobRunRequest',
  full_name='CompleteJobRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='CompleteJobRunRequest.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=792,
  serialized_end=828,
)


_ADDSYSTEMREQUEST = _descriptor.Descriptor(
  name='AddSystemRequest',
  full_name='AddSystemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='AddSystemRequest.project_uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='AddSystemRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='AddSystemRequest.meta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=830,
  serialized_end=919,
)


_GETSYSTEMREQUEST = _descriptor.Descriptor(
  name='GetSystemRequest',
  full_name='GetSystemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='GetSystemRequest.project_uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='GetSystemRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=921,
  serialized_end=974,
)


_SYSTEMINFORESPONSE = _descriptor.Descriptor(
  name='SystemInfoResponse',
  full_name='SystemInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='SystemInfoResponse.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='SystemInfoResponse.project_uid', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='SystemInfoResponse.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_name', full_name='SystemInfoResponse.project_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='SystemInfoResponse.error', index=4,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1092,
)


_ADDSYSTEMVERSIONREQUEST = _descriptor.Descriptor(
  name='AddSystemVersionRequest',
  full_name='AddSystemVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='system_uid', full_name='AddSystemVersionRequest.system_uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='AddSystemVersionRequest.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='AddSystemVersionRequest.inputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='AddSystemVersionRequest.outputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1095,
  serialized_end=1231,
)


_ADDSYSTEMVERSIONRESPONSE = _descriptor.Descriptor(
  name='AddSystemVersionResponse',
  full_name='AddSystemVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='AddSystemVersionResponse.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='AddSystemVersionResponse.error', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1233,
  serialized_end=1298,
)


_GETDATASETREQUEST = _descriptor.Descriptor(
  name='GetDatasetRequest',
  full_name='GetDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='GetDatasetRequest.project_uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='GetDatasetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1300,
  serialized_end=1354,
)


_CREATEDATASETREQUEST = _descriptor.Descriptor(
  name='CreateDatasetRequest',
  full_name='CreateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='CreateDatasetRequest.project_uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CreateDatasetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='CreateDatasetRequest.meta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1356,
  serialized_end=1450,
)


_DATASETINFORESPONSE = _descriptor.Descriptor(
  name='DatasetInfoResponse',
  full_name='DatasetInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='DatasetInfoResponse.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='DatasetInfoResponse.project_uid', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='DatasetInfoResponse.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_name', full_name='DatasetInfoResponse.project_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_timestamp', full_name='DatasetInfoResponse.update_timestamp', index=4,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_format', full_name='DatasetInfoResponse.data_format', index=5,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='DatasetInfoResponse.description', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_id', full_name='DatasetInfoResponse.location_id', index=7,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_uri', full_name='DatasetInfoResponse.location_uri', index=8,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='DatasetInfoResponse.error', index=9,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1453,
  serialized_end=1681,
)


_GETLASTDATASETVERSIONREQUEST = _descriptor.Descriptor(
  name='GetLastDatasetVersionRequest',
  full_name='GetLastDatasetVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='GetLastDatasetVersionRequest.project_uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataset_uid', full_name='GetLastDatasetVersionRequest.dataset_uid', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=1755,
)


_DATASETVERSIONRESPONSE = _descriptor.Descriptor(
  name='DatasetVersionResponse',
  full_name='DatasetVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='DatasetVersionResponse.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no_version', full_name='DatasetVersionResponse.no_version', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='DatasetVersionResponse.error', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1757,
  serialized_end=1840,
)


_DATASETCHANGESET = _descriptor.Descriptor(
  name='DatasetChangeSet',
  full_name='DatasetChangeSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_uid', full_name='DatasetChangeSet.dataset_uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_version_uid', full_name='DatasetChangeSet.parent_version_uid', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='items', full_name='DatasetChangeSet.items', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clean_slate', full_name='DatasetChangeSet.clean_slate', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='DatasetChangeSet.remove', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='DatasetChangeSet.inputs', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1843,
  serialized_end=2010,
)


_DATASETCOMMIT = _descriptor.Descriptor(
  name='DatasetCommit',
  full_name='DatasetCommit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='DatasetCommit.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasets', full_name='DatasetCommit.datasets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2012,
  serialized_end=2079,
)


_COMMITREQUEST = _descriptor.Descriptor(
  name='CommitRequest',
  full_name='CommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='CommitRequest.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasets', full_name='CommitRequest.datasets', index=1,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2081,
  serialized_end=2148,
)


_COMMITRESPONSE = _descriptor.Descriptor(
  name='CommitResponse',
  full_name='CommitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataset_versions', full_name='CommitResponse.dataset_versions', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='CommitResponse.error', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2150,
  serialized_end=2218,
)


_STATREQUEST = _descriptor.Descriptor(
  name='StatRequest',
  full_name='StatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2220,
  serialized_end=2233,
)


_STATRESPONSE = _descriptor.Descriptor(
  name='StatResponse',
  full_name='StatResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='StatResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='StatResponse.error', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2235,
  serialized_end=2292,
)


_UPDATEDATASETREQUEST = _descriptor.Descriptor(
  name='UpdateDatasetRequest',
  full_name='UpdateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='UpdateDatasetRequest.uid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meta', full_name='UpdateDatasetRequest.meta', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2294,
  serialized_end=2366,
)


_APIERROR = _descriptor.Descriptor(
  name='ApiError',
  full_name='ApiError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='ApiError.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='ApiError.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject_uid', full_name='ApiError.subject_uid', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject_name', full_name='ApiError.subject_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_name', full_name='ApiError.field_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='ApiError.details', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_name', full_name='ApiError.project_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project_uid', full_name='ApiError.project_uid', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method_name', full_name='ApiError.method_name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2369,
  serialized_end=2567,
)


_EMPTYRESPONSE = _descriptor.Descriptor(
  name='EmptyResponse',
  full_name='EmptyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='EmptyResponse.error', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2569,
  serialized_end=2610,
)

_CREATEPROJECTREQUEST.fields_by_name['meta'].message_type = vo__pb2._PROJECTMETADATADELTA
_PROJECTINFORESPONSE.fields_by_name['error'].message_type = _APIERROR
_CREATEJOBREQUEST.fields_by_name['meta'].message_type = vo__pb2._JOBMETADATADELTA
_JOBINFORESPONSE.fields_by_name['error'].message_type = _APIERROR
_STARTJOBRUNREQUEST.fields_by_name['inputs'].message_type = vo__pb2._JOBRUNINPUT
_JOBRUNINFORESPONSE.fields_by_name['error'].message_type = _APIERROR
_ADDSYSTEMREQUEST.fields_by_name['meta'].message_type = vo__pb2._SYSTEMMETADATADELTA
_SYSTEMINFORESPONSE.fields_by_name['error'].message_type = _APIERROR
_ADDSYSTEMVERSIONREQUEST.fields_by_name['inputs'].message_type = vo__pb2._SYSTEMVERSIONINPUT
_ADDSYSTEMVERSIONREQUEST.fields_by_name['outputs'].message_type = vo__pb2._SYSTEMVERSIONOUTPUT
_ADDSYSTEMVERSIONRESPONSE.fields_by_name['error'].message_type = _APIERROR
_CREATEDATASETREQUEST.fields_by_name['meta'].message_type = vo__pb2._DATASETMETADATADELTA
_DATASETINFORESPONSE.fields_by_name['error'].message_type = _APIERROR
_DATASETVERSIONRESPONSE.fields_by_name['error'].message_type = _APIERROR
_DATASETCHANGESET.fields_by_name['items'].message_type = vo__pb2._DATASETITEM
_DATASETCHANGESET.fields_by_name['inputs'].message_type = vo__pb2._DATASETVERINPUT
_DATASETCOMMIT.fields_by_name['datasets'].message_type = _DATASETCHANGESET
_COMMITREQUEST.fields_by_name['datasets'].message_type = _DATASETCHANGESET
_COMMITRESPONSE.fields_by_name['error'].message_type = _APIERROR
_STATRESPONSE.fields_by_name['error'].message_type = _APIERROR
_UPDATEDATASETREQUEST.fields_by_name['meta'].message_type = vo__pb2._DATASETMETADATADELTA
_APIERROR.fields_by_name['code'].enum_type = _STATUSCODE
_EMPTYRESPONSE.fields_by_name['error'].message_type = _APIERROR
DESCRIPTOR.message_types_by_name['CreateProjectRequest'] = _CREATEPROJECTREQUEST
DESCRIPTOR.message_types_by_name['GetProjectRequest'] = _GETPROJECTREQUEST
DESCRIPTOR.message_types_by_name['ProjectInfoResponse'] = _PROJECTINFORESPONSE
DESCRIPTOR.message_types_by_name['CreateJobRequest'] = _CREATEJOBREQUEST
DESCRIPTOR.message_types_by_name['GetJobRequest'] = _GETJOBREQUEST
DESCRIPTOR.message_types_by_name['JobInfoResponse'] = _JOBINFORESPONSE
DESCRIPTOR.message_types_by_name['StartJobRunRequest'] = _STARTJOBRUNREQUEST
DESCRIPTOR.message_types_by_name['JobRunInfoResponse'] = _JOBRUNINFORESPONSE
DESCRIPTOR.message_types_by_name['LogJobRunRequest'] = _LOGJOBRUNREQUEST
DESCRIPTOR.message_types_by_name['FailJobRunRequest'] = _FAILJOBRUNREQUEST
DESCRIPTOR.message_types_by_name['CompleteJobRunRequest'] = _COMPLETEJOBRUNREQUEST
DESCRIPTOR.message_types_by_name['AddSystemRequest'] = _ADDSYSTEMREQUEST
DESCRIPTOR.message_types_by_name['GetSystemRequest'] = _GETSYSTEMREQUEST
DESCRIPTOR.message_types_by_name['SystemInfoResponse'] = _SYSTEMINFORESPONSE
DESCRIPTOR.message_types_by_name['AddSystemVersionRequest'] = _ADDSYSTEMVERSIONREQUEST
DESCRIPTOR.message_types_by_name['AddSystemVersionResponse'] = _ADDSYSTEMVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['GetDatasetRequest'] = _GETDATASETREQUEST
DESCRIPTOR.message_types_by_name['CreateDatasetRequest'] = _CREATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['DatasetInfoResponse'] = _DATASETINFORESPONSE
DESCRIPTOR.message_types_by_name['GetLastDatasetVersionRequest'] = _GETLASTDATASETVERSIONREQUEST
DESCRIPTOR.message_types_by_name['DatasetVersionResponse'] = _DATASETVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['DatasetChangeSet'] = _DATASETCHANGESET
DESCRIPTOR.message_types_by_name['DatasetCommit'] = _DATASETCOMMIT
DESCRIPTOR.message_types_by_name['CommitRequest'] = _COMMITREQUEST
DESCRIPTOR.message_types_by_name['CommitResponse'] = _COMMITRESPONSE
DESCRIPTOR.message_types_by_name['StatRequest'] = _STATREQUEST
DESCRIPTOR.message_types_by_name['StatResponse'] = _STATRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDatasetRequest'] = _UPDATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['ApiError'] = _APIERROR
DESCRIPTOR.message_types_by_name['EmptyResponse'] = _EMPTYRESPONSE
DESCRIPTOR.enum_types_by_name['StatusCode'] = _STATUSCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateProjectRequest = _reflection.GeneratedProtocolMessageType('CreateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateProjectRequest)
  })
_sym_db.RegisterMessage(CreateProjectRequest)

GetProjectRequest = _reflection.GeneratedProtocolMessageType('GetProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:GetProjectRequest)
  })
_sym_db.RegisterMessage(GetProjectRequest)

ProjectInfoResponse = _reflection.GeneratedProtocolMessageType('ProjectInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTINFORESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:ProjectInfoResponse)
  })
_sym_db.RegisterMessage(ProjectInfoResponse)

CreateJobRequest = _reflection.GeneratedProtocolMessageType('CreateJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEJOBREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateJobRequest)
  })
_sym_db.RegisterMessage(CreateJobRequest)

GetJobRequest = _reflection.GeneratedProtocolMessageType('GetJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:GetJobRequest)
  })
_sym_db.RegisterMessage(GetJobRequest)

JobInfoResponse = _reflection.GeneratedProtocolMessageType('JobInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBINFORESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:JobInfoResponse)
  })
_sym_db.RegisterMessage(JobInfoResponse)

StartJobRunRequest = _reflection.GeneratedProtocolMessageType('StartJobRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTJOBRUNREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:StartJobRunRequest)
  })
_sym_db.RegisterMessage(StartJobRunRequest)

JobRunInfoResponse = _reflection.GeneratedProtocolMessageType('JobRunInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBRUNINFORESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:JobRunInfoResponse)
  })
_sym_db.RegisterMessage(JobRunInfoResponse)

LogJobRunRequest = _reflection.GeneratedProtocolMessageType('LogJobRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGJOBRUNREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:LogJobRunRequest)
  })
_sym_db.RegisterMessage(LogJobRunRequest)

FailJobRunRequest = _reflection.GeneratedProtocolMessageType('FailJobRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _FAILJOBRUNREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:FailJobRunRequest)
  })
_sym_db.RegisterMessage(FailJobRunRequest)

CompleteJobRunRequest = _reflection.GeneratedProtocolMessageType('CompleteJobRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEJOBRUNREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:CompleteJobRunRequest)
  })
_sym_db.RegisterMessage(CompleteJobRunRequest)

AddSystemRequest = _reflection.GeneratedProtocolMessageType('AddSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDSYSTEMREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:AddSystemRequest)
  })
_sym_db.RegisterMessage(AddSystemRequest)

GetSystemRequest = _reflection.GeneratedProtocolMessageType('GetSystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSYSTEMREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:GetSystemRequest)
  })
_sym_db.RegisterMessage(GetSystemRequest)

SystemInfoResponse = _reflection.GeneratedProtocolMessageType('SystemInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMINFORESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:SystemInfoResponse)
  })
_sym_db.RegisterMessage(SystemInfoResponse)

AddSystemVersionRequest = _reflection.GeneratedProtocolMessageType('AddSystemVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDSYSTEMVERSIONREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:AddSystemVersionRequest)
  })
_sym_db.RegisterMessage(AddSystemVersionRequest)

AddSystemVersionResponse = _reflection.GeneratedProtocolMessageType('AddSystemVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDSYSTEMVERSIONRESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:AddSystemVersionResponse)
  })
_sym_db.RegisterMessage(AddSystemVersionResponse)

GetDatasetRequest = _reflection.GeneratedProtocolMessageType('GetDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:GetDatasetRequest)
  })
_sym_db.RegisterMessage(GetDatasetRequest)

CreateDatasetRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:CreateDatasetRequest)
  })
_sym_db.RegisterMessage(CreateDatasetRequest)

DatasetInfoResponse = _reflection.GeneratedProtocolMessageType('DatasetInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASETINFORESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:DatasetInfoResponse)
  })
_sym_db.RegisterMessage(DatasetInfoResponse)

GetLastDatasetVersionRequest = _reflection.GeneratedProtocolMessageType('GetLastDatasetVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLASTDATASETVERSIONREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:GetLastDatasetVersionRequest)
  })
_sym_db.RegisterMessage(GetLastDatasetVersionRequest)

DatasetVersionResponse = _reflection.GeneratedProtocolMessageType('DatasetVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASETVERSIONRESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:DatasetVersionResponse)
  })
_sym_db.RegisterMessage(DatasetVersionResponse)

DatasetChangeSet = _reflection.GeneratedProtocolMessageType('DatasetChangeSet', (_message.Message,), {
  'DESCRIPTOR' : _DATASETCHANGESET,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:DatasetChangeSet)
  })
_sym_db.RegisterMessage(DatasetChangeSet)

DatasetCommit = _reflection.GeneratedProtocolMessageType('DatasetCommit', (_message.Message,), {
  'DESCRIPTOR' : _DATASETCOMMIT,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:DatasetCommit)
  })
_sym_db.RegisterMessage(DatasetCommit)

CommitRequest = _reflection.GeneratedProtocolMessageType('CommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMMITREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:CommitRequest)
  })
_sym_db.RegisterMessage(CommitRequest)

CommitResponse = _reflection.GeneratedProtocolMessageType('CommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMITRESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:CommitResponse)
  })
_sym_db.RegisterMessage(CommitResponse)

StatRequest = _reflection.GeneratedProtocolMessageType('StatRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:StatRequest)
  })
_sym_db.RegisterMessage(StatRequest)

StatResponse = _reflection.GeneratedProtocolMessageType('StatResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATRESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:StatResponse)
  })
_sym_db.RegisterMessage(StatResponse)

UpdateDatasetRequest = _reflection.GeneratedProtocolMessageType('UpdateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASETREQUEST,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateDatasetRequest)
  })
_sym_db.RegisterMessage(UpdateDatasetRequest)

ApiError = _reflection.GeneratedProtocolMessageType('ApiError', (_message.Message,), {
  'DESCRIPTOR' : _APIERROR,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:ApiError)
  })
_sym_db.RegisterMessage(ApiError)

EmptyResponse = _reflection.GeneratedProtocolMessageType('EmptyResponse', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYRESPONSE,
  '__module__' : 'mlp_api_pb2'
  # @@protoc_insertion_point(class_scope:EmptyResponse)
  })
_sym_db.RegisterMessage(EmptyResponse)



_CATALOG = _descriptor.ServiceDescriptor(
  name='Catalog',
  full_name='Catalog',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2985,
  serialized_end=3967,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateProject',
    full_name='Catalog.CreateProject',
    index=0,
    containing_service=None,
    input_type=_CREATEPROJECTREQUEST,
    output_type=_PROJECTINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetProject',
    full_name='Catalog.GetProject',
    index=1,
    containing_service=None,
    input_type=_GETPROJECTREQUEST,
    output_type=_PROJECTINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddSystem',
    full_name='Catalog.AddSystem',
    index=2,
    containing_service=None,
    input_type=_ADDSYSTEMREQUEST,
    output_type=_SYSTEMINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSystem',
    full_name='Catalog.GetSystem',
    index=3,
    containing_service=None,
    input_type=_GETSYSTEMREQUEST,
    output_type=_SYSTEMINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddSystemVersion',
    full_name='Catalog.AddSystemVersion',
    index=4,
    containing_service=None,
    input_type=_ADDSYSTEMVERSIONREQUEST,
    output_type=_ADDSYSTEMVERSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateJob',
    full_name='Catalog.CreateJob',
    index=5,
    containing_service=None,
    input_type=_CREATEJOBREQUEST,
    output_type=_JOBINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetJob',
    full_name='Catalog.GetJob',
    index=6,
    containing_service=None,
    input_type=_GETJOBREQUEST,
    output_type=_JOBINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StartJobRun',
    full_name='Catalog.StartJobRun',
    index=7,
    containing_service=None,
    input_type=_STARTJOBRUNREQUEST,
    output_type=_JOBRUNINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LogJobRun',
    full_name='Catalog.LogJobRun',
    index=8,
    containing_service=None,
    input_type=_LOGJOBRUNREQUEST,
    output_type=_EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FailJobRun',
    full_name='Catalog.FailJobRun',
    index=9,
    containing_service=None,
    input_type=_FAILJOBRUNREQUEST,
    output_type=_EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CompleteJobRun',
    full_name='Catalog.CompleteJobRun',
    index=10,
    containing_service=None,
    input_type=_COMPLETEJOBRUNREQUEST,
    output_type=_EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataset',
    full_name='Catalog.CreateDataset',
    index=11,
    containing_service=None,
    input_type=_CREATEDATASETREQUEST,
    output_type=_DATASETINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataset',
    full_name='Catalog.GetDataset',
    index=12,
    containing_service=None,
    input_type=_GETDATASETREQUEST,
    output_type=_DATASETINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataset',
    full_name='Catalog.UpdateDataset',
    index=13,
    containing_service=None,
    input_type=_UPDATEDATASETREQUEST,
    output_type=_EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetLastDatasetVersion',
    full_name='Catalog.GetLastDatasetVersion',
    index=14,
    containing_service=None,
    input_type=_GETLASTDATASETVERSIONREQUEST,
    output_type=_DATASETVERSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Commit',
    full_name='Catalog.Commit',
    index=15,
    containing_service=None,
    input_type=_COMMITREQUEST,
    output_type=_COMMITRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Stat',
    full_name='Catalog.Stat',
    index=16,
    containing_service=None,
    input_type=_STATREQUEST,
    output_type=_STATRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CATALOG)

DESCRIPTOR.services_by_name['Catalog'] = _CATALOG

# @@protoc_insertion_point(module_scope)



from typing import Optional

from .cl_bases import *
from . import vo_pb2 as vo

from .cl_job import Job
from .cl_dataset import Dataset
from .cl_system import System

class MultiCommit:
    def __init__(self, ctx, project_uid, clean_slate):
        """

        :type clean_slate: bool
        :type project_uid: bytes
        :type ctx: Context
        """
        self.clean_slate = clean_slate
        self.project_uid = project_uid
        self.ctx = ctx


class Systems:
    def __init__(self, ctx: Context, uid: bytes):
        self.uid = uid
        self.ctx = ctx


    def get_or_add_report(self, name: str) -> System:
        return self._get_or_add(name, kind=vo.SystemKind.Report)


    def add_report(self, name:str, title: Optional[str] = None) -> System:
        return self._add(name, vo.SystemKind.Report, title)


    def add_db(self, name:str, title: Optional[str] = None) -> System:
        return self._add(name, vo.SystemKind.Database, title)

    def add_table(self, name:str, title: Optional[str] = None) -> System:
        return self._add(name, vo.SystemKind.Table, title)



    def add_service(self, name:str, title: Optional[str] = None) -> System:
        return self._add(name, vo.SystemKind.Service, title)



    def _add(self, name: str, kind: vo.SystemKind, title: Optional[str] = None) -> System:
        meta = vo.SystemMetadataDelta()

        meta.kind = kind
        meta.kind_set = True

        if title:
            meta.title = title
            meta.title_set = True

        new = api.AddSystemRequest(
            project_uid=self.uid,
            name=name,
            meta=meta,
        )
        resp = self.ctx.add_system(new)
        return System(
            self.ctx,
            project_uid=self.uid,
            uid=resp.uid,
            name=name,
        )
    def get(self, name:str) -> System:

        req = api.GetSystemRequest(
            project_uid=self.uid,
            name=name
        )
        resp = self.ctx.get_system(req)

        return System(self.ctx, project_uid=self.uid, uid=resp.uid, name=name)

    def _get_or_add(self, name: str, kind: vo.SystemKind) -> System:
        try:
            return self.get(name)
        except errors.NotFound:
            pass

        return self._add(name, kind)


class Project:


    def __init__(self, ctx: Context, uid: bytes):
        self.uid = uid
        self.ctx = ctx
        self.systems = Systems(ctx, uid)


    def prepare_commit(self, clean_slate:bool = False):
        return MultiCommit(self.ctx, self.uid, clean_slate)


    def create_job(self, name:str, title:Optional[str]=None) -> Job:
        meta = vo.JobMetadataDelta()
        if title:
            meta.title = title
            meta.title_set = True

        create = api.CreateJobRequest(project_uid=self.uid, name=name,meta=meta)


        resp = self.ctx.create_job(create)
        return Job(self.ctx, self.uid, resp.uid, resp.name)

    def get_job(self, name:str) -> Job:
        get = api.GetJobRequest(project_uid=self.uid, name=name)
        resp = self.ctx.get_job(get)

        return Job(self.ctx, self.uid, resp.uid, resp.name)

    def get_or_create_job(self, name: str) -> Job:
        try:
            return self.get_job(name)
        except errors.NotFound:
            pass

        return self.create_job(name)


    def get_dataset(self, name) -> Dataset:

        get = api.GetDatasetRequest(project_uid=self.uid, name=name)
        resp = self.ctx.get_dataset(get)



        return Dataset(self.ctx, self.uid, resp.uid, resp.name,
                       location_id=resp.location_id)

    def create_dataset(self, name, location_id: Optional[str] = None,
                       title: Optional[str] = None, data_format: Optional[str] = None,
                       description: Optional[str] = None) -> Dataset:
        meta = vo.DatasetMetadataDelta(

        )
        if title:
            meta.title_set=True
            meta.title=title


        if data_format:
            meta.data_format=data_format
            meta.data_format_set=True

        if description:
            meta.description=description
            meta.description_set=True



        new = api.CreateDatasetRequest(
            project_uid=self.uid,
            name=name,
            meta=meta
        )

        resp = self.ctx.create_dataset(new)
        return Dataset(
            self.ctx,
            project_uid=self.uid,
            uid=resp.uid,
            name=name,
            location_id=location_id,
        )

    def get_or_create_dataset(self, name: str, location_id: Optional[str]=None) -> Dataset:
        try:
            return self.get_dataset(name)
        except errors.NotFound:
            pass

        return self.create_dataset(name, location_id=location_id)





from typing import Optional, List, Any, Union

from .cl_bases import *
from . import vo_pb2 as vo


class System(SystemId):
    def __init__(self, ctx: Context, project_uid: bytes, uid: bytes, name: str):
        super().__init__(uid)
        self.name = name

        self.project_uid = project_uid
        self.ctx = ctx

    def add_version(self, title:Optional[str]=None, inputs:List[Union[SystemId, JobRunId]]=(), outputs:List[SystemId]=()):


        api_inputs = []

        for x in inputs:
            if isinstance(x, SystemId):
                api_inputs.append(vo.SystemVersionInput(uid=x.uid, type=vo.SystemVersionInput.Type.System))
                continue
            if isinstance(x, JobRunId):
                api_inputs.append(vo.SystemVersionInput(uid=x.uid, type=vo.SystemVersionInput.Type.JobRun))
                continue

            raise ValueError(f'Unexpected input {x.__class__}')

        api_outputs = []
        for x in outputs:
            if isinstance(x, SystemId):
                api_outputs.append(vo.SystemVersionOutput(uid=x.uid, type=vo.SystemVersionOutput.Type.System))
                continue

            raise ValueError(f'Unexpected outputs {x.__class__}')

        r = api.AddSystemVersionRequest(
            system_uid=self.uid,
            title=title,
            inputs=api_inputs,
            outputs=api_outputs,
        )
        self.ctx.add_system_version(r)




import sys
import platform
import traceback
import locale
import struct
from typing import Optional, Union, List
from .deps import get_package_info
from .cl_bases import Context
from . import vo_pb2 as vo


from .cl_dataset import *


class JobRun(JobRunId):
    def __init__(self, ctx: Context, project_uid, job_uid, uid):
        super().__init__(uid)
        self.uid = uid
        self.job_uid = job_uid
        self.project_uid = project_uid
        self.ctx = ctx

    # TODO: cache this thing per run
    def log_version_info(self):
        (sysname, nodename, release, version, machine, processor) = platform.uname()

        bits = struct.calcsize("P") * 8
        host = [
            ("python", "%d.%d.%d.%s.%s" % sys.version_info[:] + " {0} bit".format(bits)),
            ("OS", "{0} {1}".format(sysname, release)),
            ("machine", machine),
            ("node", platform.node()),
            ("processor", processor),
            ("byteorder", sys.byteorder)
        ]

        host.extend(get_package_info(['pandas', 'numpy', 'bokeh', 'lz4','grpc','google.protobuf']))

        log = "\n".join([k + ": " + str(v) for k,v in host])
        self.log(log)


    def log(self, details: str, title: Optional[str] = None):

        req = api.LogJobRunRequest(
            uid=self.uid,
            details=details,
            log_title=title
        )

        self.ctx.log_job_run(req)

    def complete(self):
        req = api.CompleteJobRunRequest(
            uid=self.uid
        )
        self.ctx.complete_job_run(req)

    def fail(self, message:Optional[str]=None):

        req = api.FailJobRunRequest(
            uid=self.uid,
            message=message,
            details=traceback.format_exc()
        )
        self.ctx.fail_job_run(req)




class Job:
    def __init__(self, ctx:Context, project_uid, uid, name):
        self.name = name
        self.uid = uid
        self.project_uid = project_uid
        self.ctx = ctx

    def start_run(self, inputs:List[Union[DatasetVersionId, SystemId]], title: Optional[str]=None) -> JobRun:

        req = api.StartJobRunRequest(
            project_uid=self.project_uid,
            job_uid=self.uid,
            title=title,

        )

        for i in inputs:
            if isinstance(i, DatasetVersionId):
                req.inputs.append(vo.JobRunInput(uid=i.uid, type=vo.JobRunInput.Type.DatasetVer))
                continue
            if isinstance(i, SystemId):
                req.inputs.append(vo.JobRunInput(uid=i.uid, type=vo.JobRunInput.Type.System))
                continue
            raise ValueError(f"Unexpected job run input {i.__class__}")
        resp = self.ctx.start_job_run(req)


        return JobRun(self.ctx, self.project_uid, self.uid, resp.uid)


